#!/bin/bash
set -euf -o pipefail
shopt -s inherit_errexit

TXT_RED="\e[31m"
TXT_BLUE="\e[94m"
TXT_GREEN="\e[32m"
TXT_CLEAR="\e[0m"
TXT_BOLD="\e[1m"

function error {
    : "${RV:=${2:-$BUILD_FAILURE_EXIT_CODE}}"
    echo -e "${TXT_RED}${TXT_BOLD}$1${TXT_CLEAR}" >&2
    return "$RV"
}

[ -z "${CUSTOM_ENV_AUTH_USER:+x}" ] && error "AUTH_USER CI/CD variable has not been set."
[ -z "${CUSTOM_ENV_AUTH_KEY:+x}" ] && error "AUTH_KEY secret CI/CD variable has not been set."

AUTH_PUB="/etc/gitlab-runner/auth/${CUSTOM_ENV_CI_SERVER_HOST}/${CUSTOM_ENV_CI_PROJECT_NAMESPACE}/${CUSTOM_ENV_CI_PROJECT_NAME}/authorized_keys"
if [[ ! -f "$AUTH_PUB" ]]; then
    error "Authentication for user $AUTH_USER not configured for this project."
fi

AUTH_USER=$CUSTOM_ENV_AUTH_USER

AUTH_USER_WORK=$(runuser "$AUTH_USER" --login --command "echo \$WORK")

[ -z "${AUTH_USER_WORK:+x}" ] && error "Could not determine $AUTH_USER's \$WORK directory."

cat << EOS
{

  "builds_dir": "$AUTH_USER_WORK/gitlab-runner/builds/$CUSTOM_ENV_CI_CONCURRENT_PROJECT_ID",
  "cache_dir": "$AUTH_USER_WORK/gitlab-runner/cache",
  "builds_dir_is_shared": false,
  "driver": {
    "name": "Testcluster CI"
  }
}
EOS

